import { HttpRequestSender } from '@dmitryrechkin/request-sender-core';
import {} from './Type/NylasAuthentication.js';
export class NylasRequestSender extends HttpRequestSender {
    auth;
    /**
     * Constructor.
     *
     * @param {TypeNylasAuthentication} auth
     */
    constructor(auth) {
        super();
        this.auth = auth;
    }
    /**
     * Sends a request to the Nylas API
     *
     * @param {string} path - The endpoint URL
     * @param {RequestInit} options - The request options (method, headers, body, etc.)
     * @param {boolean} includeGrantId - Whether to include the grant ID in the URL
     * @returns {Promise<Response>} - A promise that resolves to the response
     */
    async send(path, options = {}, includeGrantId = true) {
        const headers = new Headers(options.headers || {});
        // eslint-disable-next-line @typescript-eslint/naming-convention
        headers.append('Authorization', `Bearer ${this.auth.apiKey}`);
        // eslint-disable-next-line @typescript-eslint/naming-convention
        headers.append('Content-Type', 'application/json');
        const url = this.auth.apiUrl + '/v3' + (includeGrantId ? `/grants/${this.auth.grantId}` : '') + path;
        return super.send(url, {
            ...options,
            headers
        });
    }
}
